@@ -3,7 +3,10 @@
 import collections
 import functools
 import html
+import random
 import re
+import secrets
+import string
 import urllib.parse
 
 import pymince.algorithm
@@ -19,12 +22,27 @@ _email_address_regexp = re.compile(r"^\S+@\S+$")
 _roman_regex = re.compile(r"^M{0,3}(CM|CD|D?C{0,3})(XC|XL|L?X{0,3})(IX|IV|V?I{0,3})$")
 
 
-def remove_number_commas(string):
+def get_random_string(length, alphabet=string.ascii_letters):
+    """Generate random string."""
+
+    return "".join(random.choice(alphabet) for _ in range(length))
+
+
+def get_random_secret(length, alphabet=string.ascii_letters):
+    """
+    Generate a cryptographically secure random string.
+    Useful for creating temporary passwords.
+    """
+
+    return "".join(secrets.choice(alphabet) for _ in range(length))
+
+
+def remove_number_commas(s):
     """
     Removes commas from a formatted text number having commas
     as group separator.
 
-    :param str string:
+    :param str s:
     :rtype str
 
     Examples:
@@ -32,7 +50,7 @@ def remove_number_commas(string):
         remove_number_commas('1,234,567.8') # --> '1234567.8'
     """
 
-    return __remove_number_commas(string)
+    return __remove_number_commas(s)
 
 
 def replace(value, old_values, new_value, count=-1):
@@ -59,6 +77,33 @@ def replace(value, old_values, new_value, count=-1):
     return value
 
 
+def multireplacer(replacements):
+    """
+    Given a replacement map, returns a function that can be reused to replace any string.
+
+    :param Union[dict[str, str], tuple[tuple[str, str], ...] replacements:
+        2-dict or 2-tuples with value to find and value to replace
+    :rtype: Callable[[str], str]
+
+     Examples:
+        from pymince.text import multireplacer
+
+        mapping = (("abc", "123"), ("def", "456"))
+        replace = multireplacer(mapping)
+
+        replace("...def...")  # --> "...456..."
+        replace("...abc...")  # --> "...123..."
+        replace("...abc...def...")  # --> "...123...456..."
+    """
+
+    mapper = dict(replacements)  # ensure dict
+    # Place longer ones first to keep shorter substrings from matching
+    # where the longer ones should take place.
+    values = map(re.escape, sorted(dict(mapper), key=len, reverse=True))
+    regexp = re.compile('|'.join(values))
+    return functools.partial(regexp.sub, lambda match: mapper[match.group(0)])
+
+
 def multireplace(text, replacements):
     """
     Given a string and a replacement map, it returns the replaced string.
@@ -76,14 +121,7 @@ def multireplace(text, replacements):
 
     """
 
-    if not replacements:
-        return text
-    mapper = dict(replacements)  # ensure dict
-    # Place longer ones first to keep shorter substrings from matching
-    # where the longer ones should take place.
-    values = map(re.escape, sorted(dict(mapper), key=len, reverse=True))
-    regexp = re.compile('|'.join(values))
-    return regexp.sub(lambda match: mapper[match.group(0)], text)
+    return multireplacer(replacements)(text) if replacements else text
 
 
 def remove_decimal_zeros(value, decimal_sep=".", min_decimals=None):
